async function loadCompanies (selector) {
  const sessionUUID = getData('session_uuid');
  const sessionData = await send(`session/${sessionUUID}?without_project_data=1`);

  if (sessionData) {
    addArrayToDOM(sessionData.companies, selector, 'uuid', 'name', getData('company_uuid'));
    return sessionUUID;
  }
}

async function loadProjects (companyUUID, selector) {
  const companyData = await send(`company/${companyUUID}?without_project_data=1`);

  if (companyData) {
    addArrayToDOM(companyData.projects, selector, 'uuid', 'name', getData('project_uuid'), true);
    return companyUUID;
  }
}

async function generateSecretKey (selector, defaultProjectUUID = null) {
  const projectUUID = defaultProjectUUID || selector.value;

  const permissions = await send('keys/permissions');
  if (permissions) {
    const projectData = await send('key', {
      key: {
        description: 'Adobe extension key',
        scope: 'project',
        project_uuids: [projectUUID],
        permissions: permissions.permissions.map((permi) => permi.id),
      }
    });

    if (projectData) {
      const container = selector.options[selector.selectedIndex].dataset.container;
      saveData('secret_key', projectData.new_key);
      saveData('container', container);
      saveData('project_uuid', projectUUID);
    }
  }
}

async function generateAccessKey () {
  return (await send(`project/${getData('project_uuid')}`)).keychain.tokens.airstore_key;
}

function hideLoader () {
  const loader = document.querySelector('.loading-container');
  console.log(loader);
  if (loader) {
    loader.classList.add('hide');
  }
}

function showLoader () {
  const loader = document.querySelector('.loading-container');
  if (loader) {
    loader.classList.remove('hide');
  }
}