const csInterface = new CSInterface();

if (getData('secret_key') && getData('container')) {
  initUploader();
} else {
  login();
}

async function initUploader() {
  const container = getData('container');
  const accessKey = await generateAccessKey();

  const uploader = Uploader.Core()
    .use(Uploader.FileExplorer, {
      target: '#filerobot-tab',
      inline: true,
      showBar: false,
      noImgOperationsAndDownload: true,
      replaceTargetContent: true,
      height: 470,
      metaFields: [
        { id: 'name', name: 'Name', placeholder: 'file name' },
        { id: 'caption', name: 'Caption', placeholder: 'add description' }
      ],
      config: { ...UPLOADER_CONFIG, container, uploadKey: accessKey, cloudimageToken: container }
    })
    .use(Uploader.XHRUpload, {
      endpoint: `https://api.filerobot.com/${getData('container')}/v3/upload`,
      formData: true,
      fieldName: 'files[]',
      headers: {
        'X-Filerobot-Key': accessKey
      }
    })
    .on('select', function (selectedFiles) {
      for (var i = 0; i < selectedFiles.length; i++) {
        handleFileSelection(selectedFiles[i]);
      }
    })

  // Setting flyout menu
  csInterface.setPanelFlyoutMenu(FLYOUT_MENU);
  csInterface.addEventListener("com.adobe.csxs.events.flyoutMenuClicked", flyoutMenuItemClickedHandler);

  function flyoutMenuItemClickedHandler (event) {
    const data = event.data;
    if (data.menuId === 'upload') {
      csInterface.evalScript('getActiveDocument()', handleFileDocumentUploading);
    }
    if (data.menuId === 'preferences') {
      document.querySelector('#preferences-tab').classList.add('show');
      preferences();
    }
    if (data.menuId === 'logOut') {
      removeData(['user_uuid', 'session_uuid', 'company_uuid', 'secret_key', 'container', 'user_email']);
      location.reload();
    }
  }

  function handleFileSelection(file) {
    downloadAndExecFunction(
      getFileLink(file),
      file.name,
      csInterface,
      function (downloadedFile) {
        csInterface.evalScript(
          parseInt(
            getData('open_as_layer')
          ) ? 'openAsLayer("' + downloadedFile + '")' : 'openAsDocument("' + downloadedFile + '")'
        );
      }
    );
  }

  function handleFileDocumentUploading(fileDocumentFullPathAndName) {
    const [fileDocumentFullPath, fileDocumentName] = fileDocumentFullPathAndName.split('--filerobot--');
    const { type } = getFileNameAndMimeType(fileDocumentName);
    const fileData = readFile(fileDocumentFullPath, csInterface, type);
    const newFile = { name: fileDocumentName, data: fileData, type };
    uploader.addFile(newFile);
    uploader.upload();
  }

  hideLoader();
}