function getFileLink (file = {}, defaultValue = '') {
  const url = file.url || {};

  return url.cdn || url.public || url.permalink || defaultValue;
};

function cleanFileName (name) {
  name = name.split(' ').join('-');
  return name.replace(/\W/g, '');
};

function isWindowsOs() {
    return window.navigator.platform.toLowerCase().indexOf('win') > -1;
}

function getExtTempFolderPath(csInterface) {
  const tempFolderName = 'com.filerobot.uploader/';
  let tempFolder = '/tmp/' + tempFolderName;
  if (isWindowsOs()) {
    tempFolder = csInterface.getSystemPath(SystemPath.USER_DATA) + '/../Local/Temp/' + tempFolderName;
  }
  return tempFolder;
}

function createFolder (folderPath = '') {
  window.cep.fs.makedir(folderPath);
  return folderPath;
};

function createExtTempFolder (csInterface) {
  return createFolder(
    getExtTempFolderPath(csInterface)
  );
};

function downloadAndExecFunction (url, nameWithType, csInterface, executeFunction) {
  const xhr = new XMLHttpRequest();
  xhr.open('GET', url, true);
  xhr.responseType = 'arraybuffer';
  xhr.onload = function (e) {
    if (this.status == 200 || this.status == 304) {
      const uInt8Array = new Uint8Array(this.response);
      let i = uInt8Array.length;
      const binaryString = new Array(i);
      while (i--)
        binaryString[i] = String.fromCharCode(uInt8Array[i]);
      const data = binaryString.join('');
      const base64 = window.btoa(data);

      const downloadedFile = createExtTempFolder(csInterface) + nameWithType;

      window.cep.fs.writeFile(downloadedFile, base64, cep.encoding.Base64);
      executeFunction(downloadedFile);
    }
  };
  xhr.send();
};

function readFile(fileFullPath, csInterface, contentType) {
  if (fileFullPath.startsWith('~')) {
    fileFullPath = csInterface.getSystemPath(SystemPath.USER_DATA) + '/../..' + fileFullPath.substr(1)
  }
  
  fileFullPath = decodeURI(fileFullPath);

  const result = window.cep.fs.readFile(fileFullPath, cep.encoding.Base64);
  if(result.err === 0){
    var base64Data = result.data;
    return b64toBlob(base64Data, contentType);
  } else {
    alert('Error in reading the file.');
  }
}

const b64toBlob = (b64Data, contentType='', sliceSize=512) => {
  const byteCharacters = atob(b64Data);
  const byteArrays = [];

  for (let offset = 0; offset < byteCharacters.length; offset += sliceSize) {
    const slice = byteCharacters.slice(offset, offset + sliceSize);

    const byteNumbers = new Array(slice.length);
    for (let i = 0; i < slice.length; i++) {
      byteNumbers[i] = slice.charCodeAt(i);
    }

    const byteArray = new Uint8Array(byteNumbers);
    byteArrays.push(byteArray);
  }

  const blob = new Blob(byteArrays, { type: contentType });
  return blob;
}

function getFileNameAndMimeType(fileFullName) {
  const lastDotIndex = fileFullName.lastIndexOf('.');
  let name = fileFullName;
  let type = '';

  if (lastDotIndex !== -1) {
    name = fileFullName.substr(0, lastDotIndex);
    type = MIME_TYPES[fileFullName.substr(lastDotIndex + 1)];
  }

  return { name, type };
}

function send(endpoint, data = null) {
  const baseUrl = 'https://admin.filerobot.com/api/';

  const sessionUUID = getData('session_uuid');
  const companyUUID = getData('company_uuid');
  const projectUUID = getData('project_uuid');
  const secretKey = getData('secret_key');
  
  const headers = {
    'Content-Type': 'application/json'
  };

  if (sessionUUID) { headers['X-Session-Token'] = sessionUUID; }
  if (companyUUID) { headers['X-Company-Token'] = companyUUID; }
  if (projectUUID) { headers['X-Project-Token'] = projectUUID; }
  if (secretKey) { headers['X-Filerobot-Key'] = secretKey; }

  let request
  if (data) {
    request = fetch(`${baseUrl}${endpoint}`, {
      method: 'POST',
      body: JSON.stringify(data),
      headers
    })
  } else {
    request = fetch(`${baseUrl}${endpoint}`, { headers});
  }

  return new Promise((resolve, reject) => {
    request
    .then((data) => data.json())
      .then((jsonData) => {
        const errorMsgIfThere = getErrorMsgIfFound(jsonData);
        if (errorMsgIfThere) {
          alert(errorMsgIfThere)
          resolve(null);
        }

        resolve(jsonData);
      })
    .catch((error) => reject(new Error(error)));
  });
}

function getErrorMsgIfFound(data) {
  if (data.status === 'error') {
    return data.msg;
  }

  return false;
}

function saveData(key, data) {
  window.localStorage.setItem(key, data);
}

function getData(key) {
  return window.localStorage.getItem(key);
}

function removeData(keys) {
  for (const key of keys) {
    window.localStorage.removeItem(key);
  }
}

function addArrayToDOM(arrayData, DOMParentElement, valueProp, labelProp, selectedVal = null, addContainer = false) {
  if (arrayData.length === 0) {
    DOMParentElement.innerHTML = '<option selected disabled>No data found.</option>';
    return;
  }

  DOMParentElement.innerHTML = '<option selected disabled>select...</option>';

  for (const elem of arrayData) {
    const optionElem = document.createElement('option');
    optionElem.value = elem[valueProp] || elem;
    optionElem.innerHTML = elem[labelProp] || elem;
    if (selectedVal && selectedVal === (elem[valueProp] || elem)) { optionElem.selected = true;}
    if (addContainer) {
      optionElem.dataset['container'] = elem.keychain.config.cloudimg_token;
    }
    DOMParentElement.appendChild(optionElem);
  }
}